#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['airline']

package_data = \
{'': ['*']}

setup(name='airline',
      version='0.2.0',
      description='Lightweight wide event logging to bring more observability to lambda functions.',
      author='Jonathan Stott',
      author_email='jonathan.stott@gmail.com',
      url=None,
      packages=packages,
      package_data=package_data,
     )
